# ape.managers

## Accounts

```{eval-rst}
.. automodule:: ape.managers.accounts
    :members:
    :special-members:
```

## Compilers

```{eval-rst}
.. automodule:: ape.managers.compilers
    :members:
```

## Chain

```{eval-rst}
.. autoclass:: ape.managers.chain.TransactionHistory
    :members:
    :special-members:
```

```{eval-rst}
.. autoclass:: ape.managers.chain.AccountHistory
    :members:
    :special-members:
```

```{eval-rst}
.. autoclass:: ape.managers.chain.ContractCache
    :members:
    :special-members:
```

```{eval-rst}
.. autoclass:: ape.managers.chain.BlockContainer
    :members:
    :special-members:
```

```{eval-rst}
.. autoclass:: ape.managers.chain.ChainManager
    :members:
    :special-members:
```

## Config

```{eval-rst}
.. automodule:: ape.managers.config
    :members:
    :special-members:
```

## Converters

```{eval-rst}
.. automodule:: ape.managers.converters
    :members:
```

## Networks

```{eval-rst}
.. automodule:: ape.managers.networks
    :members:
```

## Project

```{eval-rst}
.. automodule:: ape.managers.project
    :members:
    :special-members:
```

## Query

```{eval-rst}
.. automodule:: ape.managers.query
    :members:
    :special-members:
```
